@@ -216,7 +216,8 @@ next_espace()
 	if (i < 0) {
 		error(_("Out of free equation spaces."));
 #if	!SILENT
-		printf(_("Please use the clear command on unnecessary equations and try again.\n"));
+		printf(_("Use the clear command on unnecessary equations or\n"));
+		printf(_("restart with \"clear all\" and try again.\n"));
 #endif
 		longjmp(jmp_save, 3);
 	}
@@ -495,7 +496,7 @@ int	i;	/* equation space number */
 		return true;
 	}
 	if (n_lhs[i] <= 0) {
-		error(_("Equation space empty."));
+		error(_("Equation space is empty."));
 		return true;
 	}
 	return false;
@@ -908,7 +909,7 @@ long		*vp;		/* variable pointer */
 }
 
 /*
- * Return true if expression contains infinity or nan.
+ * Return true if expression contains infinity or NaN.
  */
 int
 exp_contains_infinity(p1, n1)
