@@ -1,7 +1,7 @@
 /*
  * Main include file for Mathomatic.
  *
- * Copyright (C) 1987-2006 George Gesslein II.
+ * Copyright (C) 1987-2007 George Gesslein II.
  */
 
 #define	true	1
@@ -12,15 +12,17 @@
 #endif
 
 #ifndef	max
-#define max(a, b)    (((a) > (b)) ? (a) : (b))	/* return the maximum of two values */
+#define max(a, b)    (((a) > (b)) ? (a) : (b))		/* return the maximum of two values */
 #endif
-
 #ifndef	min
-#define min(a, b)    (((a) < (b)) ? (a) : (b))	/* return the minimum of two values */
+#define min(a, b)    (((a) < (b)) ? (a) : (b))		/* return the minimum of two values */
 #endif
 
+#ifndef	INFINITY
+#define INFINITY	HUGE_VAL			/* the floating point, positive infinity constant */
+#endif
 #ifndef	isfinite
-#define	isfinite(d)	finite(d)
+#define	isfinite(d)	finite(d)			/* true if d is finite (not infinity or NaN) */
 #endif
 
 #define	ARR_CNT(a)	(sizeof(a)/sizeof(a[0]))	/* returns the number of elements in an array */
@@ -31,7 +33,7 @@
 #define	blt(dst, src, cnt)	memmove((char *) (dst), (char *) (src), (size_t) (cnt))	/* memory copy function */
 #define always_positive(power)	(fmod((double) (power), 2.0) == 0.0)	/* true if all real numbers raised to "power" result in positive, real numbers */
 
-#if	I18N	/* internationalization, translators needed! */
+#if	I18N	/* internationalization */
 #define _(str)		gettext(str)
 #else
 #define _(str)		str
@@ -76,7 +78,7 @@
 #define	MAX_VARS	500			/* maximum number of unique variables handled in each equation */
 
 #define	VAR_OFFSET	'A'			/* makes space for predefined variables */
-#define	VAR_MASK	0x3fffL			/* mask for bits containing the variable name */
+#define	VAR_MASK	0x3fffL			/* mask for bits containing a reference to the variable name */
 #define	VAR_SHIFT	14			/* number of bits set in VAR_MASK */
 #define	SUBSCRIPT_MASK	63			/* mask for variable subscript after shifting VAR_SHIFT */
 #define	MAX_SUBSCRIPT	(SUBSCRIPT_MASK - 1)	/* maximum variable subscript */
@@ -92,12 +94,12 @@ enum kind_list {		/* kinds of tokens specified in the union below */
 typedef union {
 	double	constant;	/* internal storage for mathematical constants */
 	long	variable;	/* internal storage for mathematical variables */
-/* predefined variables follow (order is important) */
+/* predefined special variables follow (order is important) */
 #define	V_NULL		0L	/* null variable (display nothing) */
-#define	V_E		1L	/* the constant "e" */
+#define	V_E		1L	/* the constant "e" or "e#" */
 #define	V_PI		2L	/* the constant "pi" */
-#define	IMAGINARY	3L	/* the imaginary constant "i#" */
-#define	SIGN		4L	/* the "sign" variable */
+#define	IMAGINARY	3L	/* the imaginary constant "i" or "i#" */
+#define	SIGN		4L	/* for "sign" variables */
 #define	MATCH_ANY	5L	/* match any variable (wild-card variable) */
 	int	operatr;	/* internal storage for mathematical operators */
 /* valid operators follow (order doesn't matter) */
@@ -122,6 +124,7 @@ typedef struct {		/* variable sort data structure */
 	int	count;		/* number of times the variable occurs */
 } sort_type;
 
+/* Debugging and error reporting macros: */
 #if	SILENT
 #define	error(str)			{ error_str = str; }	/* must be a constant string, temp strings don't work */
 #define	list_tdebug(level)
