@@ -83,11 +83,11 @@ char	*cp;
 	int	i;
 	char	buf[MAX_CMD_LEN];
 
-	i = cur_equation;
-	if (i < 0 || i >= n_equations || n_lhs[i] <= 0 || n_rhs[i] <= 0) {
+	if (cur_equation < 0 || cur_equation >= n_equations || n_lhs[cur_equation] <= 0 || n_rhs[cur_equation] <= 0) {
 		error(_("No current equation."));
 		return false;
 	}
+	i = next_espace();
 	if (*cp == '\0') {
 		my_strlcpy(prompt_str, _("Enter variable or 0: "), sizeof(prompt_str));
 		if ((cp = get_string(buf, sizeof(buf))) == NULL) {
@@ -97,12 +97,13 @@ char	*cp;
 			str_tolower(cp);
 		}
 	}
-	i = next_espace();
-	if ((cp = parse_equation(i, cp)) != NULL) {
+	if (parse_equation(i, cp)) {
 		if (n_lhs[i] && n_rhs[i]) {
 			error(_("Invalid argument."));
-		} else if (!extra_characters(cp) && solve(i, cur_equation)) {
-			return return_result(cur_equation);
+		} else {
+			if (solve(i, cur_equation)) {
+				return return_result(cur_equation);
+			}
 		}
 	}
 	n_lhs[i] = 0;
@@ -799,6 +800,9 @@ char	*cp;
 	char	*cp1;
 	char	buf[MAX_CMD_LEN];
 
+	if (test_mode) {
+		return true;
+	}
 	if (*cp == '\0') {
 		cp = _("Please press Enter");
 	}
@@ -1093,11 +1097,13 @@ char	*cp;
 		if (!get_expr(tlhs, &n_tlhs)) {
 			continue;
 		}
+		/* disguise all variables in the entered expression by making them negative: */
 		for (j = 0; j < n_tlhs; j += 2)
 			if (tlhs[j].kind == VARIABLE)
 				tlhs[j].token.variable = -tlhs[j].token.variable;
 		subst_var_with_exp(trhs, &n_trhs, tlhs, n_tlhs, v);
 	}
+	/* restore disguised variables: */
 	for (j = 0; j < n_trhs; j += 2)
 		if (trhs[j].kind == VARIABLE && trhs[j].token.variable < 0)
 			trhs[j].token.variable = -trhs[j].token.variable;
@@ -1297,8 +1303,8 @@ char	*cp;
 				return true;
 			}
 			debug_string(0, _("Simplifying both expressions..."));
-			simpa_side(lhs[i], &n_lhs[i], true);
-			simpa_side(lhs[j], &n_lhs[j], true);
+			simpa_side(lhs[i], &n_lhs[i], true, false);
+			simpa_side(lhs[j], &n_lhs[j], true, false);
 #if	!SILENT
 			if (debug_level >= 0) {
 				list_sub(i);
@@ -1329,8 +1335,8 @@ char	*cp;
 			goto times_neg1;
 		}
 		debug_string(0, _("Simplifying both equations..."));
-		simpa_side(rhs[i], &n_rhs[i], true);
-		simpa_side(rhs[j], &n_rhs[j], true);
+		simpa_side(rhs[i], &n_rhs[i], true, false);
+		simpa_side(rhs[j], &n_rhs[j], true, false);
 #if	!SILENT
 		if (debug_level >= 0) {
 			list_sub(i);
@@ -1359,8 +1365,8 @@ char	*cp;
 		return true;
 	}
 	debug_string(0, _("Simplifying both equations..."));
-	simpa_side(rhs[i], &n_rhs[i], true);
-	simpa_side(rhs[j], &n_rhs[j], true);
+	simpa_side(rhs[i], &n_rhs[i], true, false);
+	simpa_side(rhs[j], &n_rhs[j], true, false);
 	if (compare_rhs(i, j, &diff_sign)) {
 		fprintf(gfp, _("Equations are identical.\n"));
 		return true;
@@ -1435,7 +1441,7 @@ char	*cp;
 		fprintf(gfp, _("Quotient: %.*g, Remainder: %.*g\n"), precision, d3, precision, d4 * d2);
 		d1 = fabs(d1);
 		d2 = fabs(d2);
-		d3 = gcd(d1, d2);
+		d3 = gcd_verified(d1, d2);
 		if (d3 <= 0.0) {
 			fprintf(gfp, _("No GCD found.\n"));
 			return true;
@@ -1860,6 +1866,7 @@ char	*cp;
 			continue;
 		}
 do_this:
+		/* disguise all variables in the entered expression by making them negative: */
 		for (j = 0; j < n; j += 2) {
 			if (scratch[j].kind == VARIABLE) {
 				scratch[j].token.variable = -scratch[j].token.variable;
@@ -1868,6 +1875,7 @@ do_this:
 		subst_var_with_exp(tlhs, &n_tlhs, scratch, n, v);
 		subst_var_with_exp(trhs, &n_trhs, scratch, n, v);
 	}
+	/* restore disguised variables: */
 	for (j = 0; j < n_tlhs; j += 2)
 		if (tlhs[j].kind == VARIABLE && tlhs[j].token.variable < 0)
 			tlhs[j].token.variable = -tlhs[j].token.variable;
@@ -1890,7 +1898,7 @@ simplify_cmd(cp)
 char	*cp;
 {
 	int	i, j;
-	int	quick_flag = false, symb = false;
+	int	quick_flag = false, symb = false, frac = false;
 
 	for (;; cp = skip_param(cp)) {
 		if (strncasecmp(cp, "symbolic", 4) == 0) {
@@ -1901,6 +1909,10 @@ char	*cp;
 			quick_flag = true;
 			continue;
 		}
+		if (strncasecmp(cp, "fraction", 4) == 0) {
+			frac = true;
+			continue;
+		}
 		break;
 	}
 	if (!get_range_eol(&cp, &i, &j)) {
@@ -1909,8 +1921,8 @@ char	*cp;
 	symb_flag = symb;
 	for (; i <= j; i++) {
 		if (n_lhs[i]) {
-			simpa_side(lhs[i], &n_lhs[i], quick_flag);
-			simpa_side(rhs[i], &n_rhs[i], quick_flag);
+			simpa_side(lhs[i], &n_lhs[i], quick_flag, frac);
+			simpa_side(rhs[i], &n_rhs[i], quick_flag, frac);
 			return_result(i);
 		}
 	}
