@@ -359,7 +359,7 @@ char	*cp;
 			error(_("Differentiation failed."));
 			return false;
 		}
-		simpa_side(dest, &n1, true);
+		simpa_side(dest, &n1, true, false);
 	}
 	if (n_rhs[cur_equation]) {
 		blt(lhs[i], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
@@ -387,6 +387,7 @@ char	*cp;
 	if (current_not_defined()) {
 		return false;
 	}
+	i = next_espace();
 	if (n_rhs[cur_equation]) {
 		if (!solved_equation(cur_equation)) {
 			error(_("The current equation is not solved for a variable."));
@@ -426,7 +427,6 @@ char	*cp;
 		error(_("Variable not found."));
 		return false;
 	}
-	i = next_espace();
 	blt(rhs[i], source, n * sizeof(token_type));
 /* take derivatives with respect to the specified variable and simplify: */
 	for (l1 = 0; l1 < order; l1++) {
@@ -434,7 +434,7 @@ char	*cp;
 			error(_("Differentiation failed."));
 			return false;
 		}
-		simpa_side(rhs[i], &n, true);
+		simpa_side(rhs[i], &n, true, false);
 	}
 	if (!found_var(rhs[i], n, v)) {
 		error(_("There are no solutions."));
@@ -453,7 +453,7 @@ char	*cp;
 		error(_("Solve failed."));
 		return false;
 	}
-	simpa_side(rhs[i], &n_rhs[i], false);
+	simpa_side(rhs[i], &n_rhs[i], false, false);
 	return return_result(cur_equation);
 }
 
@@ -640,7 +640,7 @@ loop_again:
 				return false;
 			}
 		}
-		simpa_side(rhs[our], &our_nrhs, true);
+		simpa_side(rhs[our], &our_nrhs, true, false);
 		if (our_nrhs != 1 || rhs[our][0].kind != CONSTANT || rhs[our][0].token.constant != 0.0) {
 			i1 = n1;
 			if ((i1 + 1 + our_nrhs) > n_tokens)
@@ -686,6 +686,7 @@ char	*cp;
 	if (current_not_defined()) {
 		return false;
 	}
+	i = next_espace();
 	if (n_rhs[cur_equation] == 0) {
 /* make expression into an equation: */
 		blt(rhs[cur_equation], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
@@ -738,14 +739,13 @@ char	*cp;
 	if (extra_characters(cp))
 		return false;
 /* copy to a new equation space and work on the copy: */
-	i = next_espace();
 	copy_espace(cur_equation, i);
 	cur_equation = i;
 /* see if the limit expression contains infinity: */
 	simp_loop(tes, &n_tes);
 	infinity_flag = exp_contains_infinity(tes, n_tes);
 /* first fully simplify the current equation and group denominators together: */
-	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false);
+	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false, false);
 	group_proc(rhs[cur_equation], &n_rhs[cur_equation]);
 	found_den = complex_den = false;
 	for (j = 1; j < n_rhs[cur_equation]; j += 2) {
@@ -787,12 +787,13 @@ char	*cp;
 	}
 	if (infinity_flag ? (!complex_den && found_den) : (!found_den)) {
 /* in this case, just substitute the limit variable with the limit expression and simplify: */
+		debug_string(0, "Substituting...");
 		subst_var_with_exp(rhs[cur_equation], &n_rhs[cur_equation], tes, n_tes, v);
-		simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false);
+		simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false, false);
 		return return_result(cur_equation);
 	}
-	debug_string(1, "Taking the limit by solving...");
-	if (n_tes == 1 && tes[0].kind == CONSTANT && tes[0].token.constant == HUGE_VAL) {
+	debug_string(0, "Solving...");
+	if (n_tes == 1 && tes[0].kind == CONSTANT && tes[0].token.constant == INFINITY) {
 /* To take the limit to positive infinity, */
 /* replace infinity with zero and replace the limit variable with its reciprocal: */
 		n_tes = 1;
@@ -820,7 +821,7 @@ char	*cp;
 	n_lhs[cur_equation] = n_tes;
 /* symbolically simplify the RHS: */
 	symb_flag = true;
-	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false);
+	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false, false);
 	symb_flag = false;
 /* solve back for the original variable: */
 	if (solve_sub(&solved_v, 1, lhs[cur_equation], &n_lhs[cur_equation], rhs[cur_equation], &n_rhs[cur_equation]) <= 0) {
@@ -829,7 +830,7 @@ char	*cp;
 	}
 /* symbolically simplify before returning the result: */
 	symb_flag = true;
-	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false);
+	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false, false);
 	symb_flag = false;
 	return return_result(cur_equation);
 }
