@@ -1,7 +1,7 @@
 /*
  * General floating point GCD routine and associated code for Mathomatic.
  *
- * Copyright (C) 1987-2006 George Gesslein II.
+ * Copyright (C) 1987-2007 George Gesslein II.
  */
 
 #include "includes.h"
@@ -9,11 +9,12 @@
 /*
  * Return the Greatest Common Divisor (GCD) of doubles "d1" and "d2",
  * by using the Euclidean GCD algorithm.
- * The GCD is defined as the largest positive number that evenly divides both "d1" and "d2".
- * Will work with non-integers, but there may be some floating point error.
- * Always works correctly with integers.
  *
- * Return 0.0 on failure, otherwise return the positive GCD.
+ * The GCD is defined as the largest positive number that evenly divides both "d1" and "d2".
+ * Will usually work with non-integers, but there may be some floating point error.
+ * Always works perfectly with integers up to MAX_K_INTEGER.
+ *
+ * Return 0 on failure or if either parameter is 0, otherwise return the positive GCD.
  */
 double
 gcd(d1, d2)
@@ -58,7 +59,28 @@ double	d1, d2;
 }
 
 /*
- * Round a double to the nearest integer.
+ * Return the verified exact Greatest Common Divisor (GCD) of doubles "d1" and "d2".
+ *
+ * Return 0 on failure or if either parameter is 0, otherwise return the positive GCD.
+ */
+double
+gcd_verified(d1, d2)
+double	d1, d2;
+{
+	double	divisor;
+
+	divisor = gcd(d1, d2);
+	if (divisor != 0.0) {
+		if (fmod(d1, divisor) != 0.0)
+			return 0.0;
+		if (fmod(d2, divisor) != 0.0)
+			return 0.0;
+	}
+	return divisor;
+}
+
+/*
+ * Return a floating point double rounded to the nearest integer.
  */
 double
 my_round(d1)
@@ -80,11 +102,10 @@ double	d1;	/* value to round */
  * numerator = d / divisor
  * denominator = 1.0 / divisor
  *
- * Return true with integer numerator and denominator
- * if conversion was successful.
+ * Return true with integer numerator and denominator if conversion was successful.
  * Otherwise return false with numerator = "d" and denominator = "1.0".
  *
- * True return indicates "d" is rational, otherwise "d" is irrational.
+ * True return indicates "d" is rational and finite, otherwise "d" is irrational.
  */
 int
 f_to_fraction(d, numeratorp, denominatorp)
@@ -98,41 +119,49 @@ double	*denominatorp;	/* returned denominator */
 
 	*numeratorp = d;
 	*denominatorp = 1.0;
-/* first, see if it is an integer, or very close to an integer: */
-	if (fmod(d, 1.0) == 0.0)
+	if (!isfinite(d)) {
+		return false;
+	}
+/* see if "d" is an integer, or very close to an integer: */
+	if (fmod(d, 1.0) == 0.0) {
 		return true;
+	}
 #if	true	/* set true for more integer oriented math */
 	k3 = fabs(d) * epsilon;
 #else
 	k3 = fabs(d) * small_epsilon;
 #endif
 	k4 = my_round(d);
-	if (k4 != 0.0 && fabs(k4 - d) < k3) {
+	if (k4 != 0.0 && fabs(k4 - d) <= k3) {
 		*numeratorp = k4;
 		return true;
 	}
+/* try to convert non-integer, floating point value in "d" to a fraction: */
 	if ((divisor = gcd(1.0, d)) > epsilon) {
-		numerator = d / divisor;
-		denominator = 1.0 / divisor;
-		numerator = my_round(numerator);
-		denominator = my_round(denominator);
+		numerator = my_round(d / divisor);
+		denominator = my_round(1.0 / divisor);
+/* don't allow more than 11 digits in the numerator or denominator: */
 		if (fabs(numerator) >= 1.0e12)
 			return false;
-		if (denominator >= 1.0e12)
-			return false;
-		if (denominator < 1.5)
+		if (denominator >= 1.0e12 || denominator < 2.0)
 			return false;
 /* make sure the result is a fully reduced fraction: */
 		divisor = gcd(numerator, denominator);
 		if (divisor > 1.0) {	/* shouldn't happen, but just in case */
-			numerator = numerator / divisor;
-			denominator = denominator / divisor;
+			numerator /= divisor;
+			denominator /= divisor;
 		}
 		k3 = (numerator / denominator);
 		k4 = d;
 		if (fabs(k3 - k4) > (small_epsilon * fabs(k3))) {
 			return false;	/* result is too inaccurate */
 		}
+		if (fmod(numerator, 1.0)) {
+			error("Internal error: Numerator not integral.");
+		}
+		if (fmod(denominator, 1.0)) {
+			error("Internal error: Denominator not integral.");
+		}
 		*numeratorp = numerator;
 		*denominatorp = denominator;
 		return true;
@@ -143,6 +172,7 @@ double	*denominatorp;	/* returned denominator */
 /*
  * Convert non-integer constants in an equation side to fractions, when appropriate.
  */
+void
 make_fractions(equation, np)
 token_type	*equation;	/* equation side pointer */
 int		*np;		/* pointer to length of equation side */
