@@ -44,6 +44,7 @@ int		finance_option;				/* for displaying dollars and cents */
 int		autosolve = true;			/* Allows solving by typing the variable name at the prompt */
 int		autocalc = true;			/* Allows automatically calculating a numerical expression */
 char		special_variable_character = '\\';	/* user defined special character for variable names */
+int		integer_coefficients = true;		/* if true, prefer displaying all integer coefficients */
 #if	!SILENT
 int		debug_level;				/* current debug level */
 #endif
@@ -77,7 +78,7 @@ FILE		*gfp;			/* global output file pointer */
 jmp_buf		jmp_save;		/* for setjmp() when an error is encountered */
 int		test_mode;		/* test mode flag (-t) */
 int		quiet_mode;		/* quiet mode (don't display prompts) */
-int		html_flag;		/* true for HTML mode */
+int		html_flag;		/* true for HTML output mode */
 int		readline_enabled = true;
 int		partial_flag;		/* true for partial unfactoring of algebraic fractions */
 int		symb_flag;		/* true for "simplify symbolic" */
