@@ -12,7 +12,7 @@
  * The following structure is used for each Mathomatic command.
  */
 typedef	struct {
-	char	*name;			/* command name to be typed by user */
+	char	*name;			/* command name to be typed by user (must not contain any spaces) */
 	char	*secondary_name;	/* another name for this command */
 	int	(*func)();		/* function that handles this command */
 					/* function is passed a char pointer and returns true if successful */
@@ -79,7 +79,7 @@ static com_type com_list[] = {
 {	"save",		NULL,			save_cmd,	"file-name",						"Save all stored expressions and equations in a text file." },
 #endif
 {	"set",		NULL,			set_cmd,	"[[\"no\"] option]",					"Set or display various session options." },
-{	"simplify",	NULL,			simplify_cmd,	"[\"symbolic\"] [\"quick\"] [equation-number-range]",	"Completely simplify stored expressions." },
+{	"simplify",	NULL,			simplify_cmd,	"[\"symbolic\"] [\"quick\"] [\"fraction\"] [equation-number-range]",	"Completely simplify stored expressions." },
 {	"solve",	NULL,			solve_cmd,	"variable or \"0\"",					"Solve the current equation for a variable or for 0." },
 {	"sum",		NULL,			sum_cmd,	"variable start end [step]",				"Compute the summation as variable goes from start to end." },
 #if	!LIBRARY
@@ -103,7 +103,7 @@ parse(n, cp)
 int	n;
 char	*cp;
 {
-	if ((cp = parse_equation(n, cp)) != NULL) {
+	if (parse_equation(n, cp)) {
 		if (n_lhs[n] == 0 && n_rhs[n] == 0)
 			return true;
 		if (n_lhs[n] == 0) {
@@ -136,7 +136,7 @@ char	*cp;
 	int	i;
 #endif
 
-	if ((cp = parse_equation(n, cp)) != NULL) {
+	if (parse_equation(n, cp)) {
 		if (n_lhs[n] == 0 && n_rhs[n] == 0)
 			return true;
 		if (n_lhs[n] == 0 || n_rhs[n] == 0) {
@@ -394,7 +394,7 @@ char	*cp;	/* pointer to variable name string */
  */
 int
 display_command(i)
-int	i;	/* command index */
+int	i;	/* command table index of command */
 {
 	int	rows = 3;
 
@@ -476,24 +476,25 @@ char	*cp;
 		}
 		if (strncasecmp(cp, "expressions", cp1 - cp) == 0 || strncasecmp(cp, "equations", cp1 - cp) == 0) {
 			P("To enter an expression or equation, simply type it in at the prompt.");
-			P("Operators have precedence decreasing as indicated:\n");
+			P("Operators have precedence decreasing as indicated:");
 			P("    - negate");
 			P("    ! factorial (gamma function)");
 			P("    ** or ^ power (exponentiation)");
 			P("    * multiply        / divide          % modulus");
-			P("    + add             - subtract\n");
+			P("    + add             - subtract");
+			P("    = equate");
 			P("Operators in the same precedence level are evaluated left to right.\n");
 			P("Variables consist of any combination of letters, digits, and underscores (_).");
 			P("Constants always start with a digit (0..9) or a period (.).");
 			P("Predefined constants and variables follow:");
 			P("    e or e# - the universal constant e (2.7182818284...).");
 			P("    pi or pi# - the universal constant pi (3.1415926535...).");
-			P("    i or i# - imaginary number (square root of -1).");
+			P("    i or i# - the imaginary number (square root of -1).");
 			P("The above constants may also be used anywhere variables are required.");
 			P("    sign, sign1, sign2, sign3, ... - variable that can only be +1 or -1.");
 			P("    integer - variable that may be any integer.");
-			P("    inf - infinity constant (a true constant).\n");
-			P("Absolute value notation \"|x|\" and \"+/-\" are understood.");
+			P("    inf - infinity constant.\n");
+			P("Absolute value notation \"|x|\" and dual polarity \"+/-\" are understood.");
 			return true;
 		}
 		if (is_all(cp)) {
@@ -512,6 +513,7 @@ char	*cp;
 	}
 	/* default help text: */
 	P("This help command is provided as a quick reference.");
+	P("Full documentation is available at the website \"www.mathomatic.org\".");
 	P("Type \"help all\" for a summary and syntax of the all commands.");
 	P("Type \"help usage\" for syntax of all commands.");
 	P("Type \"help expressions\" for help with entering expressions.");
