@@ -236,11 +236,11 @@ char	*cp;
 	if (current_not_defined()) {
 		return false;
 	}
+	i = next_espace();
 	def_flag = (strcmp_tospace(cp, "definite") == 0);
 	if (def_flag) {
 		cp = skip_param(cp);
 	}
-	i = next_espace();
 	if (n_rhs[cur_equation]) {
 		source = rhs[cur_equation];
 		nps = &n_rhs[cur_equation];
@@ -311,7 +311,7 @@ char	*cp;
 		blt(&dest[n1], scratch, n2 * sizeof(token_type));
 		n1 += n2;
 	}
-	simpa_side(dest, &n1, false);
+	simpa_side(dest, &n1, false, false);
 	if (n_rhs[cur_equation]) {
 		blt(lhs[i], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
 		n_lhs[i] = n_lhs[cur_equation];
@@ -755,7 +755,7 @@ char	*cp;
 		approximate_roots = false;
 
 		if (exp_contains_infinity(dest, n1)) {
-			error(_("Integration failed because result contains infinity or nan."));
+			error(_("Integration failed because result contains infinity or NaN."));
 			return false;
 		}
 		/* detect an ever growing result: */
