@@ -43,6 +43,7 @@ int	cur_pos;	/* current position in the current line on the screen */
 /*
  * Turn color off if color mode is on.
  */
+void
 reset_attr()
 {
 	cur_color = -1;
@@ -60,6 +61,7 @@ reset_attr()
  * Set the current color on the display.
  * Range is 0 to INT_MAX.
  */
+void
 set_color(color)
 int	color;
 {
@@ -87,6 +89,7 @@ int	color;
 /*
  * Set the normal text color.
  */
+void
 default_color()
 {
 	set_color(0);
@@ -563,6 +566,7 @@ int		n;		/* length of expression */
 /*
  * Display an equation as C, Java, or Python code.
  */
+void
 list_c_equation(en, language, int_flag)
 int	en;		/* equation space number */
 int	language;
@@ -978,7 +982,15 @@ check_again:
 				cp = " - ";
 				break;
 			case TIMES:
+#if	false	/* if true use HTML times character, instead of "*" */
+				if (html_flag) {
+					cp = "&times;";
+				} else {
+					cp = "*";
+				}
+#else
 				cp = "*";
+#endif
 				break;
 			case DIVIDE:
 				cp = "/";
@@ -996,7 +1008,11 @@ check_again:
 			}
 			if (oflag)
 				fprintf(gfp, "%s", cp);
-			len += strlen(cp);
+			if (html_flag && cp[0] == '&') {
+				len++;
+			} else {
+				len += strlen(cp);
+			}
 			break;
 		}
 	}
