@@ -194,9 +194,9 @@ usage()
 	fprintf(stderr, _("  -c               Toggle color mode.\n"));
 	fprintf(stderr, _("  -h               Enable HTML output mode and disable readline.\n"));
 	fprintf(stderr, _("  -m number        Specify a memory size multiplier.\n"));
-	fprintf(stderr, _("  -q               Quiet mode (don't display prompts).\n"));
+	fprintf(stderr, _("  -q               Set quiet mode (don't display prompts).\n"));
 	fprintf(stderr, _("  -r               Disable readline.\n"));
-	fprintf(stderr, _("  -t               Used when testing.\n"));
+	fprintf(stderr, _("  -t               Set test mode.\n"));
 	fprintf(stderr, _("  -u               Set unbuffered output.\n"));
 	fprintf(stderr, _("  -v               Display version number, compile flags, and memory usage.\n"));
 	exit(1);
@@ -308,7 +308,6 @@ int	sig;
 	exit_program(1);
 }
 
-#if	TIMEOUT_SECONDS
 /*
  * Alarm signal handler.
  */
@@ -319,11 +318,11 @@ int	sig;
 	printf(_("\nTimeout, quitting...\n"));
 	exit_program(1);
 }
-#endif
 
 /*
  * Get the screen (window) width and height.
  */
+void
 get_screen_size()
 {
 	struct winsize	ws;
