@@ -1,6 +1,7 @@
 /*
  * Mathomatic simplifying and polynomial routines.
  * Includes polynomial and smart division, polynomial factoring, etc.
+ * tlhs and trhs are wiped out by most of these routines.
  *
  * The polynomial division and GCD routines here are not recursive, due to static
  * storage areas.  This limits the polynomial GCD to univariate operation.
@@ -14,9 +15,9 @@
 
 /* These are a non-standard size and must only be used for temp storage: */
 token_type	divisor[DIVISOR_SIZE];		/* static data areas for polynomial and smart division */
-int		n_divisor;
+int		n_divisor;			/* length of expression in divisor[] */
 token_type	quotient[DIVISOR_SIZE];
-int		n_quotient;
+int		n_quotient;			/* length of expression in quotient[] */
 token_type	gcd_divisor[DIVISOR_SIZE];	/* static data area for polynomial GCD routine */
 int		len_d;				/* length of expression in gcd_divisor[] */
 
@@ -41,13 +42,14 @@ sort_type	*p1, *p2;
 
 /*
  * Return true if passed expression is strictly a single polynomial term in variable v.
+ * The exponent may be anything, as long as it doesn't contain the variable.
  */
 static inline int
 poly_in_v_sub(equation, n, v, allow_divides)
 token_type	*equation;	/* expression pointer */
 int		n;		/* expression length */
 long		v;		/* variable */
-int		allow_divides;	/* allow division by variable */
+int		allow_divides;	/* if true, allow division by variable */
 {
 	int	i, k;
 	int	level, vlevel;
@@ -101,7 +103,7 @@ poly_in_v(equation, n, v, allow_divides)
 token_type	*equation;	/* expression pointer */
 int		n;		/* expression length */
 long		v;		/* variable */
-int		allow_divides;	/* allow variable to be right of a divide (negative exponents) */
+int		allow_divides;	/* allow variable to be right of a divide (negative exponents) as a polynomial term */
 {
 	int	i, j;
 
@@ -1397,7 +1399,7 @@ int		len2;		/* length of divisor */
 			}
 			flag = false;
 			j = i + 1;
-		} else if (tlhs[i].kind == VARIABLE && (tlhs[i].token.variable & VAR_MASK) > SIGN) {
+		} else if (tlhs[i].kind == VARIABLE && tlhs[i].token.variable != IMAGINARY) {
 			flag = true;
 		}
 		if (i >= n_tlhs)
