@@ -21,11 +21,12 @@ char		*skip_space(), *skip_param();
 char		*get_string();
 char		*parse_equation(), *parse_section(), *parse_var(), *parse_var2(), *parse_expr();
 char		*list_expression(), *list_equation();
-double		gcd(), my_round(), multiply_out_unique();
+double		gcd(), gcd_verified(), my_round(), multiply_out_unique();
 long		decstrtol();
 
 void fphandler(int sig);
 void inthandler(int sig);
 void alarmhandler(int sig);
+void get_screen_size(void);
 void resizehandler(int sig);
 void exit_program(int exit_value);
