@@ -18,6 +18,7 @@ static int	order_recurse();
  * Quickly and very basically simplify an equation space.
  * No factoring is done.
  */
+void
 simp_sub(n)
 int	n;	/* equation space number to simplify */
 {
@@ -32,6 +33,7 @@ int	n;	/* equation space number to simplify */
 /*
  * For quick, mid-range simplification of an expression.
  */
+void
 simp_side(equation, np)
 token_type	*equation;	/* pointer to the beginning of equation side to simplify */
 int		*np;		/* pointer to length of equation side */
@@ -42,6 +44,7 @@ int		*np;		/* pointer to length of equation side */
 /*
  * This function is the mid-range simplifier used by the solver.
  */
+void
 simps_side(equation, np, zsolve)
 token_type	*equation;	/* pointer to the beginning of equation side to simplify */
 int		*np;		/* pointer to length of equation side */
@@ -53,8 +56,9 @@ int		zsolve;		/* true if we are solving for zero */
 }
 
 /*
- * This function is used by the "factor" command.
+ * This function is used by the factor command.
  */
+void
 simpv_side(equation, np, v)
 token_type	*equation;	/* pointer to the beginning of equation side to factor */
 int		*np;		/* pointer to length of equation side */
@@ -68,6 +72,7 @@ long		v;		/* variable to factor */
 /*
  * Convert expression with any algebraic fractions into a single fraction.
  */
+void
 frac_side(equation, np)
 token_type	*equation;	/* pointer to the beginning of equation side */
 int		*np;		/* pointer to length of equation side */
@@ -83,6 +88,7 @@ int		*np;		/* pointer to length of equation side */
  * Simplify and approximate for the calculate command.
  * Includes complex number simplification.
  */
+void
 calc_simp(equation, np)
 token_type	*equation;
 int		*np;
@@ -93,7 +99,7 @@ int		*np;
 	factorv(equation, np, IMAGINARY);
 	ufactor(equation, np);
 	factorv(equation, np, IMAGINARY);
-	ufactor(equation, np);
+	uf_simp(equation, np);
 	factorv(equation, np, IMAGINARY);
 	simp_side(equation, np);
 	uf_simp(equation, np);
@@ -103,6 +109,7 @@ int		*np;
 /*
  * Try to eliminate "i#" from an equation side by converting "i#*(b^.5)" to "(-1*b)^.5".
  */
+void
 simp_i(equation, np)
 token_type	*equation;
 int		*np;
@@ -147,18 +154,23 @@ int		*np;
 
 /*
  * Main simplify code used by the simplify command.
- * "tlhs" and "trhs" are wiped out.
  * This is the slowest and most thorough simplify of all.
+ * Applies many equivalent algebraic transformations and their inverses (like unfactor and factor),
+ * then does generalized polynomial simplifications.
+ *
+ * tlhs and trhs are wiped out.
  */
-simpa_side(equation, np, quick_flag)
+void
+simpa_side(equation, np, quick_flag, frac_flag)
 token_type	*equation;	/* pointer to the beginning of equation side to simplify */
 int		*np;		/* pointer to length of the equation side */
 int		quick_flag;	/* "simplify quick" option */
+int		frac_flag;	/* if true, simplify to the ratio of two polynomials, like Maxima's ratsimp() */
 {
 	int		flag, poly_flag = true;
 	jmp_buf		save_save;
 
-	if (*np <= 1)	/* no need to simplify a constant or a variable */
+	if (*np <= 1)	/* no need to simplify a single constant or variable */
 		return;
 	partial_flag = 2;
 	simp_loop(equation, np);
@@ -241,7 +253,7 @@ do_quick:
 			}
 		}
 		/* simplify algebraic fractions with polynomial and smart division */
-		if (div_remainder(equation, np, poly_flag, quick_flag)) {
+		if (!frac_flag && div_remainder(equation, np, poly_flag, quick_flag)) {
 			flag = false;
 			simpb_side(equation, np, true, 1);
 			continue;
@@ -259,13 +271,13 @@ do_quick:
 	uf_power(equation, np);
 	integer_root_simp(equation, np);
 	simpb_side(equation, np, true, 3);
-	while (div_remainder(equation, np, poly_flag, quick_flag)) {
-		simpb_side(equation, np, true, 3);
+	if (!frac_flag) {
+		while (div_remainder(equation, np, poly_flag, quick_flag)) {
+			simpb_side(equation, np, true, 3);
+		}
 	}
 	poly_factor(equation, np);
 	simpb_side(equation, np, true, 2);
-	debug_string(1, "Result of complete simplify:");
-	side_debug(1, equation, *np);
 }
 
 /*
@@ -1774,8 +1786,9 @@ int		*np;
 }
 
 /*
- * Move the imaginary number from the denominator to the numerator.
- * Also does complex number division.
+ * Do complex number division and move the imaginary number from the denominator to the numerator.
+ * This is done by multiplying the numerator and denominator by
+ * the conjugate of the complex number in the denominator.
  * This often complicates expressions, so use with care.
  *
  * Return true if equation side was modified.
